@@ -1,5 +1,11 @@
 from djangoldp.permissions import LDPPermissions
 from django.db.models.base import ModelBase
+from django.conf import settings
+
+XMPP_SERVERS = set({'51.15.243.248', '212.47.234.179', '2001:bc8:47b0:2711::1'})
+
+if hasattr(settings, 'XMPP_SERVER_IP'):
+    XMPP_SERVERS = XMPP_SERVERS.union(getattr(settings, 'XMPP_SERVER_IP'))
 
 
 def get_client_ip(request):
@@ -64,13 +70,13 @@ class ProjectPermissions(LDPPermissions):
         return list(perms)
     
     def has_permission(self, request, view):
-        if(get_client_ip(request) == '51.15.243.248'):
+        if get_client_ip(request) in XMPP_SERVERS:
             return True
 
         return super().has_permission(request, view)
     
     def has_object_permission(self, request, view, obj):
-        if(get_client_ip(request) == '51.15.243.248'):
+        if get_client_ip(request) in XMPP_SERVERS:
             return True
 
         return super().has_object_permission(request, view, obj)
@@ -120,13 +126,13 @@ class ProjectMemberPermissions(LDPPermissions):
         return list(perms)
     
     def has_permission(self, request, view):
-        if(get_client_ip(request) == '51.15.243.248'):
+        if get_client_ip(request) in XMPP_SERVERS:
             return True
 
         return super().has_permission(request, view)
     
     def has_object_permission(self, request, view, obj):
-        if(get_client_ip(request) == '51.15.243.248'):
+        if get_client_ip(request) in XMPP_SERVERS:
             return True
 
         return super().has_object_permission(request, view, obj)
